==> simple-react-data-grid-1.0.13.tgz: package/src/components/dataGrid/tableHeader.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ArrowUp from 'react-icons/lib/fa/sort-alpha-asc';
import ArrowDown from 'react-icons/lib/fa/sort-alpha-desc';

class TableHeader extends Component {
  constructor(props) {
    super(props);
    this.onClickSort = this.onClickSort.bind(this);
    this.state = {
      isSortIcon: '',
    };
  }

  onClickSort(columnName) {
    if (this.state.isSortIcon = (this.state.isSortIcon === 'asc') ? 'desc' : 'asc') {
      this.setState({
        isSortIcon: this.state.isSortIcon,
      });
      this.props.onSort(columnName);
    }
  }

  renderSortIcon() {
    switch (this.state.isSortIcon) {
      case 'asc':
        return (
          <span style={{ float: 'right' }}><ArrowUp /></span>
        );
      case 'desc':
        return (
          <span style={{ float: 'right' }}><ArrowDown /></span>
        );
      default:
        return (
          <span />
        );
    }
  }

  render() {
    if (!this.props.metaData) {
      return null;
    }
    const
      HeaderRow = ({ metaData, styleData = {} }) => (
        <th
          style={styleData.gridTableTH}
          onClick={e => this.onClickSort(metaData.key, e)}
          id={metaData.key}
        >{metaData.name}{this.renderSortIcon()}
        </th>
      );
    return this.props.metaData.map(
      (colMetaDataHeader) => {
        if (!colMetaDataHeader) {
          return null;
        }
        return (
          <HeaderRow
            metaData={colMetaDataHeader}
            styleData={this.props.styleData}
            key={colMetaDataHeader.name}
          />
        );
      });
  }
}

TableHeader.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.array,
  styleData: PropTypes.object,
};

TableHeader.defaultProps = {
  data: [],
  metaData: {},
  styleData: {},
};

export default TableHeader;

==> simple-react-data-grid-1.0.15.tgz: package/src/components/dataGrid/tableHeader.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ArrowUp from 'react-icons/lib/fa/sort-alpha-asc';
import ArrowDown from 'react-icons/lib/fa/sort-alpha-desc';

class TableHeader extends Component {
  constructor(props) {
    super(props);
    this.onClickSort = this.onClickSort.bind(this);
    this.state = {
      sortOrder: '',
    };
  }

  onClickSort(columnName) {
    this.setState({
      sortOrder: this.state.sortOrder = (this.state.sortOrder === 'asc') ? 'desc' : 'asc',
    });
    this.props.onSort(columnName);
  }

  renderSortIcon() {
    switch (this.state.sortOrder) {
      case 'asc':
        return (
          <span className="sort-order-up"><ArrowUp /></span>
        );
      case 'desc':
        return (
          <span className="sort-order-down"><ArrowDown /></span>
        );
      default:
        return (
          <span />
        );
    }
  }

  render() {
    if (!this.props.metaData) {
      return null;
    }
    const
      HeaderRow = ({ metaData, styleData = {} }) => (
        <th
          style={styleData.gridTableTH}
          onClick={e => this.onClickSort(metaData.key, e)}
          id={metaData.key}
        >{metaData.name}{this.renderSortIcon()}
        </th>
      );
    return this.props.metaData.map(
      (colMetaDataHeader) => {
        if (!colMetaDataHeader) {
          return null;
        }
        return (
          <HeaderRow
            metaData={colMetaDataHeader}
            styleData={this.props.styleData}
            key={colMetaDataHeader.name}
          />
        );
      });
  }
}

TableHeader.propTypes = {
  metaData: PropTypes.array,
  styleData: PropTypes.object,
};

TableHeader.defaultProps = {
  metaData: {},
  styleData: {},
};

export default TableHeader;
